# bagheera-python [![Build Status](https://travis-ci.org/bagheera-lang/bagheera-python.svg?branch=main)](https://travis-ci.org/bagheera-lang/bagheera-python)


An python implementation of the bagheera programming langugage
